# Layout

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**commit_message** | **str** |  | [optional] 
**from_server_version** | [**Version**](Version.md) |  | [optional] 
**id** | **str** |  | [optional] 
**item_version** | [**Version**](Version.md) |  | [optional] 
**kind** | **str** |  | [optional] 
**modified** | **datetime** |  | [optional] 
**name** | **str** |  | [optional] 
**pack_id** | **str** |  | [optional] 
**prev_kind** | **str** |  | [optional] 
**prev_type_id** | **str** |  | [optional] 
**primary_term** | **int** |  | [optional] 
**propagation_labels** | **list[str]** |  | [optional] 
**sections** | [**list[LayoutSection]**](LayoutSection.md) |  | [optional] 
**sequence_number** | **int** |  | [optional] 
**should_commit** | **bool** |  | [optional] 
**sort_values** | **list[str]** |  | [optional] 
**system** | **bool** |  | [optional] 
**to_server_version** | [**Version**](Version.md) |  | [optional] 
**type_id** | **str** |  | [optional] 
**vc_should_ignore** | **bool** |  | [optional] 
**version** | **int** |  | [optional] 

[[Back to Model list]](README.md#documentation-for-models) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to README]](README.md)


